#ifndef TEST_OBJECT_H
#define TEST_OBJECT_H

#include "core/scene.h"
#include "core/scene_node_entity.h"
#include "core/transformable.h"
#include "core/renderable.h"
#include "utils/drop.h"
#include "utils/mirror.h"

// Test object created to generally test game features
typedef struct TestObject {
    SceneNode *node;
    Transformable transform;
    Vector2 fly_input;
    Vector2 rotation;
    bool stopped;
} TestObject;

SceneNode *CreateTestObject();
void DestroyTestObject(TestObject *self);

extern void TestObjectEnterTree(TestObject *self);
extern void TestObjectExitTree(TestObject *self);
extern void TestObjectDraw(TestObject *self);
extern void TestObjectTick(TestObject *self, double delta);

extern void TestObjectLeftInput(TestObject *self, bool value);
extern void TestObjectRightInput(TestObject *self, bool value);
extern void TestObjectUpInput(TestObject *self, bool value);
extern void TestObjectDownInput(TestObject *self, bool value);
extern void TestObjectStopInput(TestObject *self, bool value);

DECL_REFLECT(TestObject);
decl_typeclass_impl(SceneNodeEntity, TestObject);
decl_typeclass_impl(Drop, TestObject);
decl_typeclass_impl(Renderable, TestObject);

#endif // !TEST_OBJECT_H
